@@ -2,11 +2,6 @@
 # A script to calculate N50 from one or multiple FASTA/FASTQ files,
 # or from STDIN. This has been used to develop Proch::N50
 
-## THIS SCRIPT IS NOT ACTIVELY MAINTAINED:
-## ˆˆˆˆˆˆˆˆˆˆˆˆˆˆˆˆˆˆˆˆˆˆˆˆˆˆˆˆˆˆˆˆˆˆˆˆˆˆˆˆˆ
-## It's reported here for historical reasons,
-## use 'n50.pl' instead (will use Proch::N50)
-
 use 5.012;
 use warnings;
 use Pod::Usage;
@@ -16,11 +11,9 @@ use File::Basename;
 our %program = (
   'NAME'      => 'FASTx N50 CALCULATOR',
   'AUTHOR'    => 'Andrea Telatin',
-  'MAIL'      => 'andrea@telatin.com',
+  'MAIL'      => 'andrea.telatin@quadram.ac.uk',
   'VERSION'   => '1.1',
 );
-
-# Now Proch::N50 will use JSON::PP, core since 5.13.9
 my $hasJSON = eval {
 	require JSON;
 	JSON->import();
@@ -72,13 +65,11 @@ my $result = GetOptions(
 pod2usage({-exitval => 0, -verbose => 2}) if $opt_help;
 version() if defined $opt_version;
 
-# Unable to propose JSON if JSON.pm is not installed [ TODO: go to JSON:PP ]
 if ( ($opt_format=~/json/i ) and (! $hasJSON) ) {
 	die "FATAL ERROR: Please install perl module JSON first [e.g. cpanm JSON]\n";
 }
 our %output_object;
 
-# Output format
 if (defined $opt_format) {
 	$opt_format = lc($opt_format);
 	if (!$formats{$opt_format}) {
@@ -88,22 +79,17 @@ if (defined $opt_format) {
 			join(', ',@list) . ".\n";
 	}
 
-  # Warning for unimplemented formats
 	if ($formats{$opt_format} eq 'Not implemented') {
 		print STDERR " WARNING: Format '$opt_format' not implemented yet. Switching to 'tsv'.\n";
 		$opt_format = 'tsv';
 	}
 
 }
-
-# Parse all files
 foreach my $file (@ARGV) {
 
-  # Raise error if file not found (unless '-', to be used as STDIN)
 	if ( (!-e "$file") and ($file ne '-') ) {
 		die " FATAL ERROR:\n File not found ($file).\n";
 	} elsif ($file eq '-') {
-    # Set filename as <STDIN> for the output
 		$file = '<STDIN>';
 	} else {
 		open STDIN, '<', "$file" || die " FATAL ERROR:\n Unable to open file for reading ($file).\n";
@@ -148,13 +134,13 @@ if (not $opt_format or $opt_format eq 'default') {
 		}
 	}
 } elsif ($opt_format eq 'json') {
-  # JSON output
+
 	my $json = JSON->new->allow_nonref;
 	my $pretty_printed = $json->pretty->encode( \%output_object );
 	say $pretty_printed;
 
 } elsif ($opt_format eq 'tsv' or $opt_format eq 'csv') {
-  # TSV output
+
 	my @fields = ('path', 'seqs', 'size', 'N50');
 	say '#', join($opt_separator, @fields) if (!defined $opt_noheader);
 
@@ -181,7 +167,7 @@ if (not $opt_format or $opt_format eq 'default') {
 	}
 }
 
-# Print information
+
 sub debug {
 	my ($message, $title) = @_;
 	$title = 'INFO' unless defined $title;
@@ -189,8 +175,6 @@ sub debug {
 	printMessage($message, $title, 'green', 'reset');
 	return 1;
 }
-
-# Print colored message unsless --nocolor
 sub printMessage {
 	my ($message, $title, $title_color, $message_color) = @_;
 	$title_color   = 'reset' if ((!defined $title_color)  or (!colorvalid($title_color)) or (!$opt_color));
@@ -277,12 +261,11 @@ __END__
 
 =head1 NAME
 
-B<original_n50_algorithm> - A program to calculate N50 from FASTA/FASTQ files, used
-as template for Proch::N50 [n50_algorithm.pl]
+B<n50.pl> - A program to calculate N50 from FASTA/FASTQ files
 
 =head1 AUTHOR
 
-Andrea Telatin <andrea@telatin.com>
+Andrea Telatin <andrea.telatin@quadram.ac.uk>
 
 =head1 DESCRIPTION
 
@@ -293,7 +276,7 @@ printed for a single file and all metrics in TSV format for multiple files.
 
 =head1 SYNOPSIS
 
-n50_algorithm.pl [options] [FILE1 FILE2 FILE3...]
+n50.pl [options] [FILE1 FILE2 FILE3...]
 
 =head1 PARAMETERS
 
